---
name: "syncthing-rest-api"
section: "7"
platform: "linux"
package: "syncthing"
version: "2.1.7-1"
release: "Arch Linux 2026-11-01"
platforms: ["linux"]
url: "https://new.carta.tech/syncthing-rest-api"
---

# syncthing-rest-api(7)

REST API Syncthing exposes a REST interface over HTTP on the GUI port. This is used by the GUI (from Javascript) and can be used by other processes wishing to control Syncthing. In most cases both the input and output data is in JSON format. The interface is subject to change.

## NAME

syncthing-rest-api - REST API

Syncthing exposes a REST interface over HTTP on the GUI port. This is used by the GUI (from Javascript) and can be used by other processes wishing to control Syncthing. In most cases both the input and output data is in JSON format. The interface is subject to change.

## API KEY

To use the REST API an API key must be set and used. The API key can be generated in the GUI, or set in the **configuration/gui/apikey** element in the configuration file. To use an API key, set the request header **X-API-Key** to the API key value, or set it as a **Bearer** token in the **Authorization** header. For example, **curl -X POST -H "X-API-Key: abc123"** **http://localhost:8384/rest/...** or **curl -X POST -H "Authorization: Bearer** **abc123" http://localhost:8384/rest/...** can be used to invoke with **curl** (add **-k** flag when using HTTPS with a Syncthing generated or self signed certificate).

One exception to this requirement is **/rest/noauth**, you do not need an API key to use those endpoints. This way third-party devices and services can do simple calls that don’t expose sensitive information without having to expose your API key.

## RESULT PAGINATION

Some *GET* endpoints take optional **page** and **perpage** arguments for pagination.  No more than **perpage** (defaults to 65536 if not given) result entries are returned in an array.  To access further entries, passing the **page** parameter will advance in the results by that many pages.  The actually used parameters are always returned as attributes in the response object.

## SYSTEM ENDPOINTS

### GET /rest/system/browse

Returns a list of directories matching the path given by the optional parameter **current**. The path can use *patterns as described in Go’s filepath package* \<**https://pkg.go.dev/path/filepath#Match**\>. A ‘\*’ will always be appended to the given path (e.g. **/tmp/** matches all its subdirectories). If the option **current** is not given, filesystem root paths are returned.

```
$ curl -H "X-API-Key: yourkey" localhost:8384/rest/system/browse | json_pp
[
    "/"
]
$ curl -H "X-API-Key: yourkey" localhost:8384/rest/system/browse?current=/var/ | json_pp
[
    "/var/backups/",
    "/var/cache/",
    "/var/lib/",
    "/var/local/",
    "/var/lock/",
    "/var/log/",
    "/var/mail/",
    "/var/opt/",
    "/var/run/",
    "/var/spool/",
    "/var/tmp/"
]
$ curl -H "X-API-Key: yourkey" localhost:8384/rest/system/browse?current=/var/*o | json_pp
[
    "/var/local/",
    "/var/lock/",
    "/var/log/",
    "/var/opt/",
    "/var/spool/"
]
```

### GET /rest/system/config (DEPRECATED)

Deprecated since version v1.12.0: This endpoint still works as before but is deprecated. Use */rest/config* instead.

Returns the current configuration.

```
{
  "version": 35,
  "folders": [
    {
      "id": "default",
      "label": "Default Folder",
      "filesystemType": "basic",
      "path": "...",
      "type": "sendreceive",
      "devices": [
        {
          "deviceID": "...",
          "introducedBy": "",
          "encryptionPassword": ""
        }
      ],
      "rescanIntervalS": 3600,
      "fsWatcherEnabled": true,
      "fsWatcherDelayS": 10,
      "ignorePerms": false,
      "autoNormalize": true,
      "minDiskFree": {
        "value": 1,
        "unit": "%"
      },
      "versioning": {
        "type": "",
        "params": {},
        "cleanupIntervalS": 3600,
        "fsPath": "",
        "fsType": "basic"
      },
      "copiers": 0,
      "pullerMaxPendingKiB": 0,
      "hashers": 0,
      "order": "random",
      "ignoreDelete": false,
      "scanProgressIntervalS": 0,
      "pullerPauseS": 0,
      "maxConflicts": -1,
      "disableSparseFiles": false,
      "paused": false,
      "markerName": ".stfolder",
      "copyOwnershipFromParent": false,
      "modTimeWindowS": 0,
      "maxConcurrentWrites": 16,
      "disableFsync": false,
      "blockPullOrder": "standard",
      "copyRangeMethod": "standard",
      "caseSensitiveFS": false,
      "junctionsAsDirs": true
    }
  ],
  "devices": [
    {
      "deviceID": "...",
      "name": "Laptop",
      "addresses": [
        "dynamic",
        "tcp://192.168.1.2:22000"
      ],
      "compression": "metadata",
      "certName": "",
      "introducer": false,
      "skipIntroductionRemovals": false,
      "introducedBy": "",
      "paused": false,
      "allowedNetworks": [],
      "autoAcceptFolders": false,
      "maxSendKbps": 0,
      "maxRecvKbps": 0,
      "ignoredFolders": [
        {
          "time": "2022-01-09T19:09:52Z",
          "id": "br63e-wyhb7",
          "label": "Foo"
        }
      ],
      "maxRequestKiB": 0,
      "untrusted": false,
      "remoteGUIPort": 0
    }
  ],
  "gui": {
    "enabled": true,
    "address": "127.0.0.1:8384",
    "unixSocketPermissions": "",
    "user": "Username",
    "password": "$2a$10$ZFws69T4FlvWwsqeIwL.TOo5zOYqsa/.TxlUnsGYS.j3JvjFTmxo6",
    "authMode": "static",
    "useTLS": false,
    "apiKey": "k1dnz1Dd0rzTBjjFFh7CXPnrF12C49B1",
    "insecureAdminAccess": false,
    "theme": "default",
    "insecureSkipHostcheck": false,
    "insecureAllowFrameLoading": false
  },
  "ldap": {
    "address": "",
    "bindDN": "",
    "transport": "plain",
    "insecureSkipVerify": false,
    "searchBaseDN": "",
    "searchFilter": ""
  },
  "options": {
    "listenAddresses": [
      "default"
    ],
    "globalAnnounceServers": [
      "default"
    ],
    "globalAnnounceEnabled": true,
    "localAnnounceEnabled": true,
    "localAnnouncePort": 21027,
    "localAnnounceMCAddr": "[ff12::8384]:21027",
    "maxSendKbps": 0,
    "maxRecvKbps": 0,
    "reconnectionIntervalS": 60,
    "relaysEnabled": true,
    "relayReconnectIntervalM": 10,
    "startBrowser": true,
    "natEnabled": true,
    "natLeaseMinutes": 60,
    "natRenewalMinutes": 30,
    "natTimeoutSeconds": 10,
    "urAccepted": 0,
    "urSeen": 0,
    "urUniqueId": "...",
    "urURL": "https://data.syncthing.net/newdata",
    "urPostInsecurely": false,
    "urInitialDelayS": 1800,
    "autoUpgradeIntervalH": 12,
    "upgradeToPreReleases": false,
    "keepTemporariesH": 24,
    "progressUpdateIntervalS": 5,
    "limitBandwidthInLan": false,
    "minHomeDiskFree": {
      "value": 1,
      "unit": "%"
    },
    "releasesURL": "https://upgrades.syncthing.net/meta.json",
    "alwaysLocalNets": [],
    "overwriteRemoteDeviceNamesOnConnect": false,
    "tempIndexMinBlocks": 10,
    "unackedNotificationIDs": [
      "authenticationUserAndPassword"
    ],
    "trafficClass": 0,
    "setLowPriority": true,
    "maxFolderConcurrency": 0,
    "crURL": "https://crash.syncthing.net/newcrash",
    "crashReportingEnabled": true,
    "stunKeepaliveStartS": 180,
    "stunKeepaliveMinS": 20,
    "stunServers": [
      "default"
    ],
    "maxConcurrentIncomingRequestKiB": 0,
    "announceLANAddresses": true,
    "sendFullIndexOnUpgrade": false,
    "featureFlags": [],
    "connectionLimitEnough": 0,
    "connectionLimitMax": 0
  },
  "remoteIgnoredDevices": [
    {
      "time": "2022-01-09T20:02:01Z",
      "deviceID": "...",
      "name": "...",
      "address": "192.168.0.20:22000"
    }
  ],
  "defaults": {
    "folder": {
      "id": "",
      "label": "",
      "filesystemType": "basic",
      "path": "~",
      "type": "sendreceive",
      "devices": [
        {
          "deviceID": "...",
          "introducedBy": "",
          "encryptionPassword": ""
        }
      ],
      "rescanIntervalS": 3600,
      "fsWatcherEnabled": true,
      "fsWatcherDelayS": 10,
      "ignorePerms": false,
      "autoNormalize": true,
      "minDiskFree": {
        "value": 1,
        "unit": "%"
      },
      "versioning": {
        "type": "",
        "params": {},
        "cleanupIntervalS": 3600,
        "fsPath": "",
        "fsType": "basic"
      },
      "copiers": 0,
      "pullerMaxPendingKiB": 0,
      "hashers": 0,
      "order": "random",
      "ignoreDelete": false,
      "scanProgressIntervalS": 0,
      "pullerPauseS": 0,
      "maxConflicts": 10,
      "disableSparseFiles": false,
      "paused": false,
      "markerName": ".stfolder",
      "copyOwnershipFromParent": false,
      "modTimeWindowS": 0,
      "maxConcurrentWrites": 16,
      "disableFsync": false,
      "blockPullOrder": "standard",
      "copyRangeMethod": "standard",
      "caseSensitiveFS": false,
      "junctionsAsDirs": false
    },
    "device": {
      "deviceID": "",
      "name": "",
      "addresses": [
        "dynamic"
      ],
      "compression": "metadata",
      "certName": "",
      "introducer": false,
      "skipIntroductionRemovals": false,
      "introducedBy": "",
      "paused": false,
      "allowedNetworks": [],
      "autoAcceptFolders": false,
      "maxSendKbps": 0,
      "maxRecvKbps": 0,
      "ignoredFolders": [],
      "maxRequestKiB": 0,
      "untrusted": false,
      "remoteGUIPort": 0
    }
  }
}
```

### GET /rest/system/config/insync (DEPRECATED)

Deprecated since version v1.12.0: This endpoint still works as before but is deprecated. Use */rest/config/restart-required* instead.

Returns whether the config is in sync, i.e. whether the running configuration is the same as that on disk.

```
{
  "configInSync": true
}
```

### POST /rest/system/config (DEPRECATED)

Deprecated since version v1.12.0: This endpoint still works as before but is deprecated.  Use *Config Endpoints* instead.

Post the full contents of the configuration, in the same format as returned by the corresponding GET request. When posting the configuration succeeds, the posted configuration is immediately applied, except for changes that require a restart. Query */rest/config/restart-required* to check if a restart is required.

This endpoint is the main point to control Syncthing, even if the change only concerns a very small part of the config: The usual workflow is to get the config, modify the needed parts and post it again.

### GET /rest/system/connections

**NOTE:**

Return format changed in versions 0.13.0, 0.14.14, 1.2.0, 1.19.0, 1.23.0 and 1.25.0.

Returns the list of configured devices and some metadata associated with them.

The connection types are **tcp-client**, **tcp-server**, **relay-client**, **relay-server**, **quic-client** and **quic-server**.

```
{
  "connections": {
    "DOVII4U-SQEEESM-VZ2CVTC-CJM4YN5-QNV7DCU-5U3ASRL-YVFG6TH-W5DV5AA": {
      "address": "",
      "at": "0001-01-01T00:00:00Z",
      "clientVersion": "",
      "connected": false,
      "inBytesTotal": 0,
      "isLocal": false,
      "outBytesTotal": 0,
      "paused": false,
      "startedAt": "0001-01-01T00:00:00Z",
      "type": ""
    },
    "UYGDMA4-TPHOFO5-2VQYDCC-7CWX7XW-INZINQT-LE4B42N-4JUZTSM-IWCSXA4": {
      "address": "",
      "at": "0001-01-01T00:00:00Z",
      "clientVersion": "",
      "connected": false,
      "inBytesTotal": 0,
      "isLocal": false,
      "outBytesTotal": 0,
      "paused": false,
      "startedAt": "0001-01-01T00:00:00Z",
      "type": ""
    },
    "YZJBJFX-RDBL7WY-6ZGKJ2D-4MJB4E7-ZATSDUY-LD6Y3L3-MLFUYWE-AEMXJAC": {
      "address": "127.0.0.1:22002",
      "at": "2015-11-07T17:29:47.691548971+01:00",
      "clientVersion": "v0.12.1",
      "connected": true,
      "inBytesTotal": 556,
      "isLocal": true,
      "outBytesTotal": 550,
      "paused": false,
      "startedAt": "2015-11-07T00:09:47Z",
      "type": "tcp-client"
    }
  },
  "total": {
    "at": "2015-11-07T17:29:47.691637262+01:00",
    "inBytesTotal": 1479,
    "outBytesTotal": 1318
  }
}
```

### GET /rest/system/discovery

Returns the contents of the local discovery cache.

```
{
  "LGFPDIT7SKNNJVJZA4FC7QNCRKCE753K72BW5QD2FOZ7FRFEP57Q": [
    "192.162.129.11:22000"
  ]
}
```

### POST /rest/system/discovery

**NOTE:**

Removed in v0.12.0.

Post with the query parameters **device** and **addr** to add entries to the discovery cache.

```
curl -X POST http://127.0.0.1:8384/rest/system/discovery?device=LGFPDIT7SKNNJVJZA4FC7QNCRKCE753K72BW5QD2FOZ7FRFEP57Q\&addr=192.162.129.11:22000
# Or with the X-API-Key header:
curl -X POST --header "X-API-Key: TcE28kVPdtJ8COws1JdM0b2nodj77WeQ" http://127.0.0.1:8384/rest/system/discovery?device=LGFPDIT7SKNNJVJZA4FC7QNCRKCE753K72BW5QD2FOZ7FRFEP57Q\&addr=192.162.129.11:22000
```

### POST /rest/system/error/clear

Post with empty to body to remove all recent errors.

### GET /rest/system/error

**NOTE:**

Return format changed in 0.12.0.

Returns the list of recent errors.

```
{
  "errors": [
    {
      "when": "2014-09-18T12:59:26.549953186+02:00",
      "message": "This is an error string"
    }
  ]
}
```

### POST /rest/system/error

Post with an error message in the body (plain text) to register a new error. The new error will be displayed on any active GUI clients.

### GET /rest/system/log

Added in version 0.12.0.

Returns the list of recent log entries.  The optional **since** parameter limits the results to message newer than the given timestamp in *RFC 3339* \<**https://datatracker.ietf.org/doc/html/rfc3339.html**\> format.

```
{
  "messages": [
    {
      "when": "2014-09-18T12:59:26.549953186+02:00",
      "message": "This is a log entry"
    }
  ]
}
```

### GET /rest/system/log.txt

Returns the same information, formatted as a text log instead of a JSON object.

### GET /rest/system/loglevels

Added in version 2.0.0.

Returns the set of log facilities and their current log level.

```
{
  "levels": {
    "api": "INFO",
    "beacon": "INFO",
    ...
    "versioner": "INFO",
    "watchaggregator": "INFO"
  },
  "packages": {
    "api": "REST API",
    "beacon": "Multicast and broadcast discovery",
    ...
    "versioner": "File versioning",
    "watchaggregator": "Filesystem event watcher"
  }
}
```

### POST /rest/system/loglevels

Added in version 2.0.0.

Changes the log level for specified facilities. Post an object with the log facilites as keys and desired log level (**DEBUG**, **INFO**, **WARN**, or **ERROR**) as the values.

```
$ curl -H X-API-Key:abc123 -d '{"beacon":"DEBUG","discovery":"WARN"}' 'http://localhost:8384/rest/system/loglevels'
```

### GET /rest/system/paths

Added in version 1.21.0.

Returns the path locations used internally for storing configuration, database, and others.

```
{
  "auditLog": "/home/user/.local/share/syncthing/audit-${timestamp}.log",
  "baseDir-config": "/home/user/.config/syncthing",
  "baseDir-data": "/home/user/.local/share/syncthing",
  "baseDir-userHome": "/home/user",
  "certFile": "/home/user/.config/syncthing/cert.pem",
  "config": "/home/user/.config/syncthing/config.xml",
  "csrfTokens": "/home/user/.config/syncthing/csrftokens.txt",
  "database": "/home/user/.local/share/syncthing/index-v2",
  "defFolder": "/home/user/Sync",
  "guiAssets": "/home/user/src/syncthing/gui",
  "httpsCertFile": "/home/user/.config/syncthing/https-cert.pem",
  "httpsKeyFile": "/home/user/.config/syncthing/https-key.pem",
  "keyFile": "/home/user/.config/syncthing/key.pem",
  "logFile": "-",
  "panicLog": "/home/user/.local/share/syncthing/panic-${timestamp}.log"
}
```

### POST /rest/system/pause

Pause the given device or all devices.

Takes the optional parameter **device** (device ID). When omitted, pauses all devices.  Returns status 200 and no content upon success, or status 500 and a plain text error on failure.

### GET /rest/system/ping

Returns a **{"ping": "pong"}** object.

```
{
  "ping": "pong"
}
```

### POST /rest/system/ping

Returns a **{"ping": "pong"}** object.

### POST /rest/system/reset

Post with empty body to erase the current index database and restart Syncthing. With no query parameters, the entire database is erased from disk. By specifying the **folder** parameter with a valid folder ID, only information for that folder will be erased:

```
curl -X POST -H "X-API-Key: abc123" http://localhost:8384/rest/system/reset?folder=ab1c2-def3g
```

Creates **.stfolder** folders in each sync folder if they do not already exist. **Caution**: Ensure that all sync folders which are mountpoints are already mounted.  Inconsistent versions may result if the mountpoint is later mounted and contains older versions.

### POST /rest/system/restart

Post with empty body to immediately restart Syncthing.

### POST /rest/system/resume

Resume the given device or all devices.

Takes the optional parameter **device** (device ID). When omitted, resumes all devices.  Returns status 200 and no content upon success, or status 500 and a plain text error on failure.

### POST /rest/system/shutdown

Post with empty body to cause Syncthing to exit and not restart.

### GET /rest/system/status

Returns information about current system status and resource usage. The CPU percent value has been deprecated from the API and will always report 0.

```
{
  "alloc": 30618136,
  "connectionServiceStatus": {
    "dynamic+https://relays.syncthing.net/endpoint": {
      "error": null,
      "lanAddresses": [
        "relay://23.92.71.120:443/?id=53STGR7-YBM6FCX-PAZ2RHM-YPY6OEJ-WYHVZO7-PCKQRCK-PZLTP7T-434XCAD&pingInterval=1m0s&networkTimeout=2m0s&sessionLimitBps=0&globalLimitBps=0&statusAddr=:22070&providedBy=canton7"
      ],
      "wanAddresses": [
        "relay://23.92.71.120:443/?id=53STGR7-YBM6FCX-PAZ2RHM-YPY6OEJ-WYHVZO7-PCKQRCK-PZLTP7T-434XCAD&pingInterval=1m0s&networkTimeout=2m0s&sessionLimitBps=0&globalLimitBps=0&statusAddr=:22070&providedBy=canton7"
      ]
    },
    "tcp://0.0.0.0:22000": {
      "error": null,
      "lanAddresses": [
        "tcp://0.0.0.0:22000"
      ],
      "wanAddresses": [
        "tcp://0.0.0.0:22000"
      ]
    }
  },
  "cpuPercent": 0,
  "discoveryEnabled": true,
  "discoveryErrors": {
    "global@https://discovery-v4-1.syncthing.net/v2/": "500 Internal Server Error",
    "global@https://discovery-v4-2.syncthing.net/v2/": "Post https://discovery-v4-2.syncthing.net/v2/: net/http: request canceled while waiting for connection (Client.Timeout exceeded while awaiting headers)",
    "global@https://discovery-v4-3.syncthing.net/v2/": "Post https://discovery-v4-3.syncthing.net/v2/: net/http: request canceled while waiting for connection (Client.Timeout exceeded while awaiting headers)",
    "global@https://discovery-v6-1.syncthing.net/v2/": "Post https://discovery-v6-1.syncthing.net/v2/: dial tcp [2001:470:28:4d6::5]:443: connect: no route to host",
    "global@https://discovery-v6-2.syncthing.net/v2/": "Post https://discovery-v6-2.syncthing.net/v2/: dial tcp [2604:a880:800:10::182:a001]:443: connect: no route to host",
    "global@https://discovery-v6-3.syncthing.net/v2/": "Post https://discovery-v6-3.syncthing.net/v2/: dial tcp [2400:6180:0:d0::d9:d001]:443: connect: no route to host"
  },
  "discoveryStatus": {
    "IPv4 local": {
      "error": null
    },
    "IPv6 local": {
      "error": null
    },
    "global@https://discovery-v4-1.syncthing.net/v2/": {
      "error": "500 Internal Server Error"
    },
    "global@https://discovery-v4-2.syncthing.net/v2/": {
      "error": "Post https://discovery-v4-2.syncthing.net/v2/: net/http: request canceled while waiting for connection (Client.Timeout exceeded while awaiting headers)"
    },
    "global@https://discovery-v4-3.syncthing.net/v2/": {
      "error": "Post https://discovery-v4-3.syncthing.net/v2/: net/http: request canceled while waiting for connection (Client.Timeout exceeded while awaiting headers)"
    },
    "global@https://discovery-v6-1.syncthing.net/v2/": {
      "error": "Post https://discovery-v6-1.syncthing.net/v2/: dial tcp [2001:470:28:4d6::5]:443: connect: no route to host"
    },
    "global@https://discovery-v6-2.syncthing.net/v2/": {
      "error": "Post https://discovery-v6-2.syncthing.net/v2/: dial tcp [2604:a880:800:10::182:a001]:443: connect: no route to host"
    },
    "global@https://discovery-v6-3.syncthing.net/v2/": {
      "error": "Post https://discovery-v6-3.syncthing.net/v2/: dial tcp [2400:6180:0:d0::d9:d001]:443: connect: no route to host"
    }
  },
  "discoveryMethods": 8,
  "goroutines": 49,
  "lastDialStatus": {
      "tcp://10.20.30.40": {
        "when": "2019-05-16T07:41:23Z",
        "error": "dial tcp 10.20.30.40:22000: i/o timeout"
      },
      "tcp://172.16.33.3:22000": {
        "when": "2019-05-16T07:40:43Z",
        "ok": true
      },
      "tcp://83.233.120.221:22000": {
        "when": "2019-05-16T07:41:13Z",
        "error": "dial tcp 83.233.120.221:22000: connect: connection refused"
      }
  },
  "myID": "P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2",
  "pathSeparator": "/",
  "startTime": "2016-06-06T19:41:43.039284753+02:00",
  "sys": 42092792,
  "themes": [
    "default",
    "dark"
  ],
  "tilde": "/Users/jb",
  "uptime": 2635
}
```

Added in version 1.2.0: The **lastDialStatus** dictionary contains the last error (or **null** for success) for each peer address that Syncthing has attempted to contact. The **connectionServiceStatus** entries gained **"error": null** attributes where previously there would be no **error** attribute at all in the success case.

Added in version 1.18.0: The **discoveryStatus** dictionary lists all configured discovery methods, not only failed ones like the now deprecated **discoveryErrors**.  Each entry is an object itself (for consistency with other fields), where a **null** value for the **error** attribute means the method is running successfully.  This effectively deprecates the **discoveryMethods** attribute as well, which now always matches the number of entries in **discoveryStatus**.

### GET /rest/system/upgrade

Checks for a possible upgrade and returns an object describing the newest version and upgrade possibility.

```
{
  "latest": "v0.14.47",
  "majorNewer": false,
  "newer": true,
  "running": "v0.14.46"
}
```

### POST /rest/system/upgrade

Perform an upgrade to the newest released version and restart. Does nothing if there is no newer version than currently running.

### GET /rest/system/version

Returns the current Syncthing version information.

```
{
  "arch": "amd64",
  "longVersion": "syncthing v0.10.27+3-gea8c3de (go1.4 darwin-amd64 default) jb@syno 2015-03-16 11:01:29 UTC",
  "os": "darwin",
  "version": "v0.10.27+3-gea8c3de"
}
```

## CONFIG ENDPOINTS

### Config Endpoints

Added in version 1.12.0.

These endpoints facilitate access and modification of the *configuration* in a granular way. Config sent to the endpoints must be in the same format as returned by the corresponding GET request. When posting the configuration succeeds, the posted configuration is immediately applied, except for changes that require a restart. Query */rest/config/restart-required* to check if a restart is required.

For all endpoints supporting **PATCH**, it takes the existing config and unmarshals the given JSON object on top of it. This means all child objects will replace the existing objects, not extend them. For example for **RawListenAddresses** in options, which is an array of strings, sending **{RawListenAddresses: \["tcp://10.0.0.2"\]}** will replace all existing listen addresses.

### /rest/config

**GET** returns the entire config and **PUT** replaces it.

### /rest/config/restart-required

**GET** returns whether a restart of Syncthing is required for the current config to take effect.

### /rest/config/folders, /rest/config/devices

**GET** returns all folders respectively devices as an array. **PUT** takes an array and **POST** a single object. In both cases if a given folder/device already exists, it’s replaced, otherwise a new one is added.

### /rest/config/folders/\*id\*, /rest/config/devices/\*id\*

Put the desired folder- respectively device-ID in place of \*id\*. **GET** returns the folder/device for the given ID, **PUT** replaces the entire config, **PATCH** replaces only the given child objects and **DELETE** removes the folder/device.

### /rest/config/defaults/folder, /rest/config/defaults/device

**GET** returns a template folder / device configuration object with all default values, which only needs a unique ID to be applied.  **PUT** replaces the default config (omitted values are reset to the hard-coded defaults), **PATCH** replaces only the given child objects.

### /rest/config/defaults/ignores

Added in version 1.19.0.

**GET** returns an object with a single **lines** attribute listing ignore patterns to be used by default on folders, as an array of single-line strings. **PUT** replaces the default ignore patterns from an object of the same format.

### /rest/config/options, /rest/config/ldap, /rest/config/gui

**GET** returns the respective object, **PUT** replaces the entire object and **PATCH** replaces only the given child objects.

**NOTE:**

The *gui.password* configuration option has special handling to accept already hashed passwords.  Any valid bcrypt hash is stored verbatim, while a plaintext password is first hashed.

## CLUSTER ENDPOINTS

Concerns the mesh network structure.

### DELETE /rest/cluster/pending/devices

Added in version 1.18.0.

Remove records about a pending remote device which tried to connect.  Valid values for the **device** parameter are those from the corresponding *GET /rest/cluster/pending/devices* endpoint.

```
$ curl -X DELETE -H "X-API-Key: abc123" http://localhost:8384/rest/cluster/pending/devices?device=P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2
```

Returns status 200 and no content upon success, or status 500 and a plain text error on failure.  A *PendingDevicesChanged* event will be generated in response.

For a more permanent effect, also for future connections from the same device ID, the device should be ignored in the *configuration* instead.

### GET /rest/cluster/pending/devices

Added in version 1.13.0.

Lists remote devices which have tried to connect, but are not yet configured in our instance.

```
{
  "P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2": {
    "time": "2020-03-18T11:43:07Z",
    "name": "Friend Joe",
    "address": "192.168.1.2:22000"
  }
}
```

### DELETE /rest/cluster/pending/folders

Added in version 1.18.0.

Remove records about a pending folder announced from a remote device.  Valid values for the **folder** and **device** parameters are those from the corresponding *GET /rest/cluster/pending/folders* endpoint.  The **device** parameter is optional and affects announcements of this folder from the given device, or from *any* device if omitted.

```
$ curl -X DELETE -H "X-API-Key: abc123" http://localhost:8384/rest/cluster/pending/folders?folder=cpkn4-57ysy&device=P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2
```

Returns status 200 and no content upon success, or status 500 and a plain text error on failure.  A *PendingFoldersChanged* event will be generated in response.

For a more permanent effect, also for future announcements of the same folder ID, the folder should be ignored in the *configuration* instead.

### GET /rest/cluster/pending/folders

Added in version 1.13.0.

Lists folders which remote devices have offered to us, but are not yet shared from our instance to them.  Takes the optional **device** parameter to only return folders offered by a specific remote device. Other offering devices are also omitted from the result.

```
{
  "cpkn4-57ysy": {
    "offeredBy": {
      "P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2": {
        "time": "2020-03-18T11:43:07Z",
        "label": "Joe's folder",
        "receiveEncrypted": true,
        "remoteEncrypted": false
      },
      "DOVII4U-SQEEESM-VZ2CVTC-CJM4YN5-QNV7DCU-5U3ASRL-YVFG6TH-W5DV5AA": {
        "time": "2020-03-01T10:12:13Z",
        "label": "Jane's and Joe's folder",
        "receiveEncrypted": false,
        "remoteEncrypted": false
      }
    }
  },
  "abcde-fghij": {
    "offeredBy": {
      "P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2": {
        "time": "2020-03-18T11:43:07Z",
        "label": "MyPics",
        "receiveEncrypted": false,
        "remoteEncrypted": false
      }
    }
  }
}
```

## FOLDER ENDPOINTS

Runtime state of the individual shared folders.

### GET /rest/folder/errors

Added in version 0.14.53.

Takes one mandatory parameter, **folder**, and returns the list of errors encountered during scanning or pulling.

The results can be paginated using the *common pagination parameters*.

```
{
  "folder": "nnhic-sxuae",
  "errors": [
    {
      "path": "noperm.txt",
      "error": "hashing: open /path/to/folder/noperm.txt: permission denied"
    }
  ],
  "page": 1,
  "perpage": 100
}
```

### GET /rest/folder/pullerrors (DEPRECATED)

Deprecated since version v0.14.53: This endpoint still works as before but is deprecated.  Use *GET /rest/folder/errors* instead, which returns the same information.

See *https://github.com/syncthing/syncthing/commit/d510e3cca3d5caae42121fa206b3decc981ae59e*

### GET /rest/folder/versions

Added in version 0.14.44.

Takes one mandatory parameter, **folder**, and returns the list of archived files that could be recovered.  How many versions are available depends on the *File Versioning* configuration.  Each entry specifies when the file version was archived as the **versionTime**, the **modTime** when it was last modified before being archived, and the size in bytes.

```
{
  "dir1/dir2/bar": [
    {
      "versionTime": "2022-02-06T20:44:12+01:00",
      "modTime": "2021-01-14T13:21:22+01:00",
      "size": 4
    }
  ],
  "baz": [
    {
      "versionTime": "2022-02-06T20:44:20+01:00",
      "modTime": "2021-01-14T13:23:49+01:00",
      "size": 4
    }
  ],
  "foo": [
    {
      "versionTime": "2022-02-06T20:55:31+01:00",
      "modTime": "2022-02-06T20:44:13+01:00",
      "size": 4
    },
    {
      "versionTime": "2022-02-06T20:44:20+01:00",
      "modTime": "2021-01-14T13:21:16+01:00",
      "size": 4
    }
  ]
}
```

### POST /rest/folder/versions

Restore archived versions of a given set of files.  Expects an object with attributes named after the relative file paths, with timestamps as values matching valid **versionTime** entries in the corresponding *GET /rest/folder/versions* response object.

Takes the mandatory parameter **folder** (folder ID).  Returns an object containing any error messages that occurred during restoration of the file, with the file path as attribute name.

```
curl -X POST -H X-API-key:... http://127.0.0.1:8384/rest/folder/versions?folder=default -d '{
  "dir1/dir2/bar": "2022-02-06T20:44:12+01:00",
  "baz": "2022-02-06T20:44:20+01:00"
}'
```

## DATABASE ENDPOINTS

### GET /rest/db/browse

Returns the directory tree of the global model. Directories are always JSON objects (map/dictionary), and files are always arrays of modification time and size. The first integer is the files modification time, and the second integer is the file size.

The call takes one mandatory **folder** parameter and two optional parameters. Optional parameter **levels** defines how deep within the tree we want to dwell down (0 based, defaults to unlimited depth) Optional parameter **prefix** defines a prefix within the tree where to start building the structure.

```
$ curl -s http://localhost:8384/rest/db/browse?folder=j663y-3ct3e&prefix=DCIM&levels=2
[
    {
        "modTime" : "2020-10-02T23:48:52.076996974+02:00",
        "name" : "100ANDRO",
        "size" : 128,
        "type" : "FILE_INFO_TYPE_DIRECTORY"
    },
    {
        "children" : [
            {
                "modTime" : "2020-12-16T23:31:34.5009668+01:00",
                "name" : "IMG_20201114_124821.jpg",
                "size" : 10682189,
                "type" : "FILE_INFO_TYPE_FILE"
            },
            {
                "modTime" : "2020-12-16T23:31:35.0106367+01:00",
                "name" : "IMG_20201213_122451.jpg",
                "size" : 7936351,
                "type" : "FILE_INFO_TYPE_FILE"
            },
            {
                "modTime" : "2020-12-13T12:25:05.017097469+01:00",
                "name" : "IMG_20201213_122504.jpg",
                "size" : 8406507,
                "type" : "FILE_INFO_TYPE_FILE"
            },
            {
                "modTime" : "2020-12-13T12:25:06.127097469+01:00",
                "name" : "IMG_20201213_122505.jpg",
                "size" : 8381931,
                "type" : "FILE_INFO_TYPE_FILE"
            },
            {
                "modTime" : "2020-12-13T12:53:29.707298401+01:00",
                "name" : "IMG_20201213_125329.jpg",
                "size" : 4388331,
                "type" : "FILE_INFO_TYPE_FILE"
            },
        ],
        "modTime" : "2020-10-09T13:04:42.4410738+02:00",
        "name" : "Camera",
        "size" : 128,
        "type" : "FILE_INFO_TYPE_DIRECTORY"
    },
]
```

**NOTE:**

This is an expensive call, increasing CPU and RAM usage on the device. Use sparingly.

### GET /rest/db/completion

Returns the completion percentage (0 to 100) and byte / item counts. Takes optional **device** and **folder** parameters:

- •

  **folder** specifies the folder ID to calculate completion for. An empty or absent **folder** parameter means all folders as an aggregate.

- •

  **device** specifies the device ID to calculate completion for. An empty or absent **device** parameter means the local device.

If a device is specified but no folder, completion is calculated for all folders shared with that device.

### Example Queries

Completion status for folder **abcd-1234** on device **I6KAH76-...-3PSROAU**:

```
/rest/db/completion?folder=abcd-1234&device=I6KAH76-...-3PSROAU
```

Aggregated completion status for device **I6KAH76-...-3PSROAU** (all folders shared with them):

```
/rest/db/completion?device=I6KAH76-...-3PSROAU
```

Completion status for folder **abcd-1234** on the local device:

```
/rest/db/completion?folder=abcd-1234
```

Aggregated completion status for all folders on the local device:

```
/rest/db/completion
```

### Example Response

```
{
  "completion": 99.9937565835,
  "globalBytes": 156793013575,
  "needBytes": 9789241,
  "globalItems": 7823,
  "needItems": 412,
  "needDeletes": 0,
  "remoteState": "valid",
  "sequence": 12
}
```

Added in version 1.8.0: The ability to aggregate multiple folders by leaving out the folder ID. Querying data for the local device by leaving out the device ID. Returning the **globalItems** counter in the response.

Added in version 1.20.0: Indication whether the remote device has accepted the folder (shares it with us) as well, and whether it is paused.  The **remoteState** field is meaningless for aggregated responses, **unknown** when the remote device is not connected.  Otherwise it can be either **paused**, **notSharing**, or **valid** if the remote is sharing back.

### GET /rest/db/file

Returns most data about a given file, including version and availability.

### Request

The call requires parameters for **folder** and **file** in the query string:

- •

  **folder** is the folder ID which you can find in the Syncthing Web GUI, e.g. **5camp-slpa8**.

- •

  **file** is the relative path of the file starting from the folder root to the file you are interested in.  The path and filename must be correctly URL-encoded.

### Example Request

```
$ curl -s -H X-API-KEY:... "http://localhost:8384/rest/db/file?folder=YOUR_FOLDER_ID" --url-query "file=path/to/file.pdf"
```

### Response

```
{
  "availability": [
    {
      "id": "ITZRNXE-YNROGBZ-HXTH5P7-VK5NYE5-QHRQGE2-7JQ6VNJ-KZUEDIU-5PPR5AM",
      "fromTemporary": false
    }
  ],
  "global": { /* a file entry */ },
  "local": { /* a file entry */ },
  "mtime": {
    "err": null,
    "value": {
      "real": "0001-01-01T00:00:00Z",
      "virtual": "0001-01-01T00:00:00Z"
  }
}
```

**local** and **global** refer to the current file on the local device and the globally newest file, respectively.  A file entry looks like this:

```
{
  "deleted": false,
  "ignored": false,
  "inodeChange": "1970-01-01T01:00:00+01:00",
  "invalid": false,
  "localFlags": 0,
  "modified": "2022-09-28T08:07:19.979723+02:00",
  "modifiedBy": "523ITIE",
  "mustRescan": false,
  "name": "img",
  "noPermissions": false,
  "numBlocks": 0,
  "permissions": "0755",
  "platform": { /* platform specific data */ },
  "sequence": 914,
  "size": 128,
  "type": "FILE_INFO_TYPE_DIRECTORY",
  "version": [
    "523ITIE:1664345275"
  ]
}
```

Platform specific data may be ownership, extended attributes, etc. and is divided into entries per operating system / platform.  An example platform entry containing ownership information for Unix systems and an extended attribute for macOS (“darwin”) looks as follows:

```
{
  "darwin": {
    "xattrs": [
      {
        "name": "net.kastelo.xattrtest",
        "value": "aGVsbG8="
      }
    ]
  },
  "freebsd": null,
  "linux": null,
  "netbsd": null,
  "unix": {
    "gid": 20,
    "groupName": "staff",
    "ownerName": "jb",
    "uid": 501
  },
  "windows": null
}
```

### GET /rest/db/ignores

Takes one parameter, **folder**, and returns the content of the **.stignore** as the **ignore** field. A second field, **expanded**, provides a list of strings which represent globbing patterns described by gobwas/glob (based on standard wildcards) that match the patterns in **.stignore** and all the includes. If appropriate these globs are prepended by the following modifiers: **!** to negate the glob, **(?i)** to do case insensitive matching and **(?d)** to enable removing of ignored files in an otherwise empty directory.

```
{
  "ignore": [
    "(?i)/Backups"
  ],
  "expanded": [
    "(?i)Backups",
    "(?i)Backups/**"
  ]
}
```

### POST /rest/db/ignores

Expects a format similar to the output of *GET /rest/db/ignores* call, but only containing the **ignore** field (**expanded** field should be omitted). It takes one parameter, **folder**, and either updates the content of the **.stignore** echoing it back as a response, or returns an error.

### GET /rest/db/localchanged

Added in version 0.14.55.

Takes one mandatory parameter, **folder**, and returns the list of files which were changed locally in a receive-only folder.  Thus they differ from the global state and could be reverted by pulling from remote devices again, see *POST /rest/db/revert*.

The results can be paginated using the *common pagination parameters*.

```
{
  "files": [
    {
      "flags": "0755",
      "sequence": 6,
      "modified": "2015-04-20T23:06:12+09:00",
      "name": "ls",
      "size": 34640,
      "version": [
        "5157751870738175669:1"
      ]
    }
  ],
  "page": 1,
  "perpage": 100
}
```

**NOTE:**

This is an expensive call, increasing CPU and RAM usage on the device. Use sparingly.

### GET /rest/db/need

Takes one mandatory parameter, **folder**, and returns lists of files which are needed by this device in order for it to become in sync.

The results can be paginated using the *common pagination parameters*.  Pagination happens, across the union of all needed files, that is - across all 3 sections of the response.  For example, given the current need state is as follows:

- 1\.

  **progress** has 15 items

- 2\.

  **queued** has 3 items

- 3\.

  **rest** has 12 items

If you issue a query with **page=1** and **perpage=10**, only the **progress** section in the response will have 10 items. If you issue a request query with **page=2** and **perpage=10**, **progress** section will have the last 5 items, **queued** section will have all 3 items, and **rest** section will have first 2 items. If you issue a query for **page=3** and **perpage=10**, you will only have the last 10 items of the **rest** section.

**NOTE:**

Return format changed in version 0.14.43, removing the **total** count attribute.

```
{
  # Files currently being downloaded
  "progress": [
    {
      "flags": "0755",
      "sequence": 6,
      "modified": "2015-04-20T23:06:12+09:00",
      "name": "ls",
      "size": 34640,
      "version": [
        "5157751870738175669:1"
      ]
    }
  ],
  # Files queued to be downloaded next (as per array order)
  "queued": [
      ...
  ],
  # Files to be downloaded after all queued files will be downloaded.
  # This happens when we start downloading files, and new files get added while we are downloading.
  "rest": [
      ...
  ],
  "page": 1,
  "perpage": 100
}
```

**NOTE:**

This is an expensive call, increasing CPU and RAM usage on the device. Use sparingly.

### POST /rest/db/override

Request override of a send only folder. Override means to make the local version latest, overriding changes made on other devices. This API call does nothing if the folder is not a send only folder.

Takes the mandatory parameter *folder* (folder ID).

```
curl -X POST -H X-API-key:... http://127.0.0.1:8384/rest/db/override?folder=default
```

### POST /rest/db/prio

Moves the file to the top of the download queue.

```
curl -X POST http://127.0.0.1:8384/rest/db/prio?folder=default&file=foo/bar
```

Response contains the same output as *GET /rest/db/need*.

### GET /rest/db/remoteneed

Added in version 0.14.43.

Takes the mandatory parameters **folder** and **device**, and returns the list of files which are needed by that remote device in order for it to become in sync with the shared folder.

The results can be paginated using the *common pagination parameters*.

```
{
  "files": [
    {
      "flags": "0755",
      "sequence": 6,
      "modified": "2015-04-20T23:06:12+09:00",
      "name": "ls",
      "size": 34640,
      "version": [
        "5157751870738175669:1"
      ]
    }
  ],
  "page": 1,
  "perpage": 100
}
```

**NOTE:**

This is an expensive call, increasing CPU and RAM usage on the device. Use sparingly.

### POST /rest/db/revert

Added in version 0.14.50.

Request revert of a receive only folder. Reverting a folder means to undo all local changes. This API call does nothing if the folder is not a receive only folder.

Takes the mandatory parameter *folder* (folder ID).

```
curl -X POST -H X-API-Key:... http://127.0.0.1:8384/rest/db/revert?folder=default
```

### POST /rest/db/scan

Request immediate scan. Takes the optional parameters **folder** (folder ID), **sub** (path relative to the folder root) and **next** (time in seconds). If **folder** is omitted or empty all folders are scanned. If **sub** is given, only this path (and children, in case it’s a directory) is scanned. The **next** argument delays Syncthing’s automated rescan interval for a given amount of seconds.

Requesting scan of a path that no longer exists, but previously did, is valid and will result in Syncthing noticing the deletion of the path in question.

Returns status 200 and no content upon success, or status 500 and a plain text error if an error occurred during scanning.

```
curl -X POST http://127.0.0.1:8384/rest/db/scan?folder=default&sub=foo/bar
```

### GET /rest/db/status

Returns information about the current status of a folder.

Parameters: **folder**, the ID of a folder.

```
{
  "globalBytes": 0,
  "globalDeleted": 0,
  "globalDirectories": 0,
  "globalFiles": 0,
  "globalSymlinks": 0,
  "globalTotalItems": 0,
  "ignorePatterns": false,
  "inSyncBytes": 0,
  "inSyncFiles": 0,
  "invalid": "",
  "localBytes": 0,
  "localDeleted": 0,
  "localDirectories": 0,
  "localFiles": 0,
  "localSymlinks": 0,
  "localTotalItems": 0,
  "needBytes": 0,
  "needDeletes": 0,
  "needDirectories": 0,
  "needFiles": 0,
  "needSymlinks": 0,
  "needTotalItems": 0,
  "pullErrors": 0,
  "receiveOnlyChangedBytes": 0,
  "receiveOnlyChangedDeletes": 0,
  "receiveOnlyChangedDirectories": 0,
  "receiveOnlyChangedFiles": 0,
  "receiveOnlyChangedSymlinks": 0,
  "receiveOnlyTotalItems": 0,
  "sequence": 0,
  "state": "idle",
  "stateChanged": "2018-08-08T07:04:57.301064781+02:00",
  "version": 0
}
```

The various fields have the following meaning:

- **global\*:**

  Data in the cluster latest version.

- **inSync\*:**

  Data that is locally the same as the cluster latest version.

- **local\*:**

  Data that is locally present, regardless of whether it’s the same or different version as the cluster latest version.

- **need\*:**

  Data that is needed to become up to date with the cluster latest version (i.e., data that is out of sync).

- **receiveOnlyChanged\*:**

  Data that has changed locally in a receive only folder, and thus not been sent to the cluster.

- **invalid:**

  Deprecated, always empty.

- **pullErrors:**

  The number of files that failed to sync during the last sync operations.

- **sequence:**

  The current folder sequence number.

- **state:**

  The current folder state.

- **stateChanged:**

  When the folder state last changed.

- **version:**

  Deprecated, equivalent to the sequence number.

**NOTE:**

This is an expensive call, increasing CPU and RAM usage on the device. Use sparingly.

## EVENT ENDPOINTS

### GET /rest/events

To receive events, perform a HTTP GET of **/rest/events**.

To filter the event list, in effect creating a specific subscription for only the desired event types, add a parameter **events=EventTypeA,EventTypeB,...** where the event types are any of the *Event Types*.  If no filter is specified, all events *except* *LocalChangeDetected* and *RemoteChangeDetected* are included.

The optional parameter **since=\<lastSeenID\>** sets the ID of the last event you’ve already seen. Syncthing returns a JSON encoded array of event objects, starting at the event just after the one with this last seen ID. The default value is 0, which returns all events. There is a limit to the number of events buffered, so if the rate of events is high or the time between polling calls is long some events might be missed. This can be detected by noting a discontinuity in the event IDs.

If no new events are produced since **\<lastSeenID\>**, the HTTP call blocks and waits for new events to happen before returning. If **\<lastSeenID\>** is a future ID, the HTTP call blocks until such ID is reached or timeouts. By default it times out after 60 seconds returning an empty array. The time out duration can be customized with the optional parameter **timeout=\<seconds\>**.

To receive only a limited number of events, add the **limit=\<n\>** parameter with a suitable value for **n** and only the *last* **n** events will be returned. This can be used to catch up with the latest event ID after a disconnection for example: **/rest/events?since=0&limit=1**.

### GET /rest/events/disk

This convenience endpoint provides the same event stream, but pre-filtered to show only *LocalChangeDetected* and *RemoteChangeDetected* event types.  The **events** parameter is not used.

## STATISTICS ENDPOINTS

### GET /rest/stats/device

Returns general statistics about devices. Currently, only contains the time the device was last seen and the last connection duration.

```
$ curl -s http://localhost:8384/rest/stats/device | json
{
  "P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2": {
    "lastSeen" : "2015-04-18T11:21:31.3256277+01:00"
    "lastConnectionDurationS": 556335.421708141
  }
}
```

### GET /rest/stats/folder

Returns general statistics about folders. Currently contains the last scan time and the last synced file.

```
{
  "folderid": {
    "lastScan": "2016-06-02T13:28:01.288181412-04:00",
    "lastFile": {
      "filename": "file/name",
      "at": "2015-04-16T22:04:18.3066971+01:00"
    }
  }
}
```

## MISC SERVICES ENDPOINTS

### GET /rest/svc/deviceid

Verifies and formats a device ID. Accepts all currently valid formats (52 or 56 characters with or without separators, upper or lower case, with trivial substitutions). Takes one parameter, **id**, and returns either a valid device ID in modern format, or an error.

```
$ curl -s http://localhost:8384/rest/svc/deviceid?id=1234 | json
{
  "error": "device ID invalid: incorrect length"
}
$ curl -s http://localhost:8384/rest/svc/deviceid?id=p56ioi7m--zjnu2iq-gdr-eydm-2mgtmgl3bxnpq6w5btbbz4tjxzwicq | json
{
  "id": "P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2"
}
```

### GET /rest/svc/lang

Returns a list of canonicalized localization codes, as picked up from the **Accept-Language** header sent by the browser.

```
["sv_sv","sv","en_us","en"]
```

### GET /rest/svc/random/string

Returns a strong random generated string (alphanumeric) of the specified length. Takes the **length** parameter.

```
{
  "random": "FdPaEaZQ56sXEKYNxpgF"
}
```

### GET /rest/svc/report

Returns the data sent in the anonymous usage report.

```
{
   "folderMaxMiB" : 0,
   "platform" : "linux-amd64",
   "totMiB" : 0,
   "longVersion" : "syncthing v0.12.2 \"Beryllium Bedbug\" (go1.4.3 linux-amd64 default) unknown-user@build2.syncthing.net 2015-11-09 13:23:26 UTC",
   "upgradeAllowedManual" : true,
   "totFiles" : 3,
   "folderUses" : {
      "ignorePerms" : 0,
      "autoNormalize" : 0,
      "sendonly" : 0,
      "ignoreDelete" : 0
   },
   "memoryUsageMiB" : 13,
   "version" : "v0.12.2",
   "sha256Perf" : 27.28,
   "numFolders" : 2,
   "memorySize" : 1992,
   "announce" : {
      "defaultServersIP" : 0,
      "otherServers" : 0,
      "globalEnabled" : false,
      "defaultServersDNS" : 1,
      "localEnabled" : false
   },
   "usesRateLimit" : false,
   "numCPU" : 2,
   "uniqueID" : "",
   "urVersion" : 2,
   "rescanIntvs" : [
      60,
      60
   ],
   "numDevices" : 2,
   "folderMaxFiles" : 3,
   "relays" : {
      "defaultServers" : 1,
      "enabled" : true,
      "otherServers" : 0
   },
   "deviceUses" : {
      "compressMetadata" : 1,
      "customCertName" : 0,
      "staticAddr" : 1,
      "compressAlways" : 0,
      "compressNever" : 1,
      "introducer" : 0,
      "dynamicAddr" : 1
   },
   "upgradeAllowedAuto" : false
}
```

## DEBUG ENDPOINTS

### Debug Endpoints

### GET /rest/debug/cpuprof

Used to capture a profile of what Syncthing is doing on the CPU.  See *Profiling*.

### GET /rest/debug/heapprof

Used to capture a profile of what Syncthing is doing with the heap memory.  See *Profiling*.

### GET /rest/debug/support

Collects information about the running instance for troubleshooting purposes. Returns a “support bundle” as a zipped archive, which should be sent to the developers after verifying it contains no sensitive personal information. Credentials for the web GUI and the API key are automatically redacted already.

### GET /rest/debug/file

Shows diagnostics about a certain file in a shared folder.  Takes the **folder** (folder ID) and **file** (folder relative path) parameters.

```
$ curl -H X-API-Key:... "http://localhost:8384/rest/debug/file?folder=default&file=foo/bar"
```

The returned object contains the same info as *GET /rest/db/file*, plus a summary of **globalVersions**.

## NOAUTH ENDPOINTS

Calls that do not require authentication.

### GET /rest/noauth/health

Returns a **{"status": "OK"}** object.

```
{
  "status": "OK"
}
```

## AUTHOR

The Syncthing Authors

## COPYRIGHT

2014-2026, The Syncthing Authors
